function [beta, gamma_t, delta_t, gamma1, gamma2, x1, V1, loglik,xsmooth] = ...
    Estep(y, A, C, Q, R, initx, initV)
%
% Compute the (expected) sufficient statistics for a single Kalman filter sequence.
%
% Source: "Does real-time macroeconomic information help to predict interest rates?" 
% by Alberto Caruso and Laura Coroneo, Journal of Money, Credit and Banking, 
% Forthcoming

% Contact Author: Laura Coroneo
% e-mail address: laura.coroneo@york.ac.uk
% Release date: 24/10/22

[os, T] = size(y);
ss = size(A,1);

[xsmooth, Vsmooth, VVsmooth, loglik] = runKF_tv(y, A, C, Q, R, initx, initV);

gamma = zeros(ss, ss);
beta = zeros(ss, ss);

delta_t = zeros(os, ss, T);
gamma_t = zeros (ss, ss, T);
    
for t=1:T
    delta_t(:,:,t)=  y(:,t)*xsmooth(:,t)';
    delta_t(isnan(y(:,t)),:,t) = 0;
    gamma_t(:,:,t) =  xsmooth(:,t)*xsmooth(:,t)' + Vsmooth(:,:,t);
    gamma = gamma + gamma_t(:,:,t);
    if t>1; beta = beta + xsmooth(:,t)*xsmooth(:,t-1)' + VVsmooth(:,:,t); end
end
gamma1 = gamma - xsmooth(:,T)*xsmooth(:,T)' - Vsmooth(:,:,T);
gamma2 = gamma - xsmooth(:,1)*xsmooth(:,1)' - Vsmooth(:,:,1);

x1 = xsmooth(:,1);
V1 = Vsmooth(:,:,1);

