function C = restr_corr(delta_t,gamma_t,S,RRR_y,qqq_y,RRR_x,qqq_x, RRR_q,qqq_q)

% This function perfoms the restricted maximization for the factor loadings

% Source: "Does real-time macroeconomic information help to predict interest rates?" 
% by Alberto Caruso and Laura Coroneo, Journal of Money, Credit and
% Banking, Forthcoming

% Contact Author: Laura Coroneo
% e-mail address: laura.coroneo@york.ac.uk
% Release date: 24/10/22

T = size(S,3);
N = size(S,1);
ns = size(gamma_t,1);

gammaS = zeros(ns*N,ns*N);

for t=1:T
    gammaS = gammaS + kron(gamma_t(:,:,t), S(:,:,t));
end

deltaS =sum(delta_t,3);
Cvec = pinv(gammaS)* deltaS(:);

C = reshape(Cvec, N, length(Cvec)/N);

n_y = size(qqq_y,1);
n_x = size(qqq_x,1);
n_q = size(qqq_q,1);

gamma= sum(gamma_t,3);
inv_gamma = pinv(gamma);

if n_y>0
    C(1:n_y,:) = C(1:n_y,:) - (C(1:n_y,:)*RRR_y -qqq_y)*...
        pinv(RRR_y'*inv_gamma*RRR_y)*RRR_y*inv_gamma;
end

if n_x>0
    C(n_y+1:n_y+n_x,:) = C(n_y+1:n_y+n_x,:) - (C(n_y+1:n_y+n_x,:)*RRR_x - qqq_x)*...
        pinv(RRR_x'*inv_gamma*RRR_x)*RRR_x*inv_gamma;
end

if n_q>0
    C(n_y+n_x+1: end,:) = C(n_y+n_x+1: end,:) - (C(n_y+n_x+1: end,:)*RRR_q - qqq_q)*...
        pinv(RRR_q'*inv_gamma*RRR_q)*RRR_q*inv_gamma;
end

C(abs(C)<0.001)=0;